==> mintty-1~3.6.2-1.src.tar.zst: mintty-3.6.2/README.md <==
Mintty is the [Cygwin](http://cygwin.com) Terminal emulator, 
also available for [MSYS](http://mingw.org/wiki/MSYS) 
and [Msys2](https://github.com/msys2).

### Overview ###

For an introduction, features overview, and screenshots, see the 
[<img align=absmiddle src=icon/terminal.ico>Mintty homepage](http://mintty.github.io/),
with an opportunity to donate to appreciate mintty.

For detailed hints and specific issues, see the [Wiki](https://github.com/mintty/mintty/wiki).

For comprehensive general documentation, see the [manual page](http://mintty.github.io/mintty.1.html).

### Bugs and Enhancements ###

Please report bugs or suggest enhancements via the [issue tracker](https://github.com/mintty/mintty/issues).

Bugs that were reported to the previous repository at Google code before June, 2015, have been migrated here.

  * Mind! Before reporting an issue about character interaction with an application, please check the issue also with at least one other terminal (xterm, urxvt), and maybe the Cygwin Console. 
    It may also be useful to get a proper understanding of the rôle of a terminal as explained e.g. in [difference between a 'terminal', a 'shell', a 'tty' and a 'console'](http://unix.stackexchange.com/questions/4126/what-is-the-exact-difference-between-a-terminal-a-shell-a-tty-and-a-con).

### Contribution ###

If you consider to suggest a patch or contribute to mintty otherwise, discuss your proposal in an issue first, or on the Cygwin mailing list, or with the maintainer.

  * Repository policy: No unsolicited pull requests!

==> mintty-1~3.6.3-1.src.tar.zst: mintty-3.6.3/README.md <==
Mintty is the [Cygwin](http://cygwin.com) Terminal, 
as well as the 
[terminal emulator](http://en.wikipedia.org/wiki/Terminal_emulator) 
for MSYS 
([Msys2](https://github.com/msys2), 
[old MSYS](https://web.archive.org/web/20201223203407/http://www.mingw.org/)).

### Overview ###

For an introduction, features overview, and screenshots, see the 
[<img align=absmiddle src=icon/terminal.ico>Mintty homepage](http://mintty.github.io/).

For detailed hints and specific issues, see the [Wiki](https://github.com/mintty/mintty/wiki).

For comprehensive general documentation, see the [manual page](http://mintty.github.io/mintty.1.html).

### Bugs and Enhancements ###

Please report bugs or suggest enhancements via the [issue tracker](https://github.com/mintty/mintty/issues).

Bugs that were reported to the previous repository at Google code before June, 2015, have been migrated here.

  * Mind! Before reporting an issue about character interaction with an application, please check the issue also with at least one other terminal (xterm, urxvt), and maybe the Cygwin Console. 
    It may also be useful to get a proper understanding of the rôle of a terminal as explained e.g. in [difference between a 'terminal', a 'shell', a 'tty' and a 'console'](http://unix.stackexchange.com/questions/4126/what-is-the-exact-difference-between-a-terminal-a-shell-a-tty-and-a-con).

### Contribution ###

If you consider to suggest a patch or contribute to mintty otherwise, discuss your proposal in an issue first, or on the Cygwin mailing list, or with the maintainer.

  * Repository policy: No unsolicited pull requests!
